==> hawkular-accounts-api-1.0.15.Final-sources.jar: org/hawkular/accounts/api/internal/impl/ResourceServiceImpl.java <==
/*
 * Copyright 2015 Red Hat, Inc. and/or its affiliates
 * and other contributors as indicated by the @author tags.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.hawkular.accounts.api.internal.impl;

import java.util.List;

import javax.annotation.security.PermitAll;
import javax.ejb.Stateless;
import javax.inject.Inject;
import javax.persistence.EntityManager;
import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Root;

import org.hawkular.accounts.api.NamedRole;
import org.hawkular.accounts.api.ResourceService;
import org.hawkular.accounts.api.internal.adapter.HawkularAccounts;
import org.hawkular.accounts.api.model.Persona;
import org.hawkular.accounts.api.model.PersonaResourceRole;
import org.hawkular.accounts.api.model.Resource;
import org.hawkular.accounts.api.model.Resource_;
import org.hawkular.accounts.api.model.Role;

/**
 * Main implementation of the {@link org.hawkular.accounts.api.ResourceService}. Consumers should get an instance of
 * this via CDI. This class should not be directly instantiated by the consumers.
 *
 * @author Juraci Paixão Kröhling
 */
@Stateless
@PermitAll
public class ResourceServiceImpl implements ResourceService {
    @Inject @HawkularAccounts
    EntityManager em;

    @Inject
    Persona persona;

    @Inject
    @NamedRole("SuperUser")
    Role superUser;

    @Override
    public Resource get(String id) {
        if (null == id) {
            throw new IllegalArgumentException("The given resource ID is invalid (null).");
        }

        CriteriaBuilder builder = em.getCriteriaBuilder();
        CriteriaQuery<Resource> query = builder.createQuery(Resource.class);
        Root<Resource> root = query.from(Resource.class);
        query.select(root);
        query.where(builder.equal(root.get(Resource_.id), id));

        List<Resource> results = em.createQuery(query).getResultList();
        if (results.size() == 1) {
            return results.get(0);
        }

        if (results.size() > 1) {
            throw new IllegalStateException("More than one resource found for ID " + id);
        }

        return null;
    }

    @Override
    public Resource create(String id, Persona persona) {
        if (null == persona) {
            throw new IllegalArgumentException("The specified persona is invalid (null).");
        }
        return create(id, null, persona);
    }

    @Override
    public Resource create(String id, Resource parent) {
        if (null == parent) {
            throw new IllegalArgumentException("The given parent resource is invalid (null).");
        }
        return create(id, parent, null);
    }

    @Override
    public Resource create(String id, Resource parent, Persona persona) {
        if (null == parent && null == persona) {
            throw new IllegalArgumentException("Either parent or persona should be provided when creating a resource");
        }

        Resource resource = new Resource(id, persona, parent);
        em.persist(resource);

        if (persona != null) {
            PersonaResourceRole resourceRole = new PersonaResourceRole(persona, superUser, resource);
            em.persist(resourceRole);
        }

        return resource;
    }

    @Override
    public void delete(String id) {
        if (null == id) {
            throw new IllegalArgumentException("The given resource ID is invalid (null).");
        }

        Resource resource = get(id);
        if (resource != null) {
            em.remove(resource);
        }
    }

    @Override
    public List<Resource> getByPersona(Persona persona) {
        if (null == persona) {
            throw new IllegalArgumentException("The given persona is invalid (null).");
        }

        CriteriaBuilder builder = em.getCriteriaBuilder();
        CriteriaQuery<Resource> query = builder.createQuery(Resource.class);
        Root<Resource> root = query.from(Resource.class);
        query.select(root);
        query.where(builder.equal(root.get(Resource_.persona), persona));

        return em.createQuery(query).getResultList();
    }
}

==> hawkular-accounts-api-1.0.16.Final-sources.jar: org/hawkular/accounts/api/internal/impl/ResourceServiceImpl.java <==
/*
 * Copyright 2015 Red Hat, Inc. and/or its affiliates
 * and other contributors as indicated by the @author tags.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.hawkular.accounts.api.internal.impl;

import java.util.List;

import javax.annotation.security.PermitAll;
import javax.ejb.Stateless;
import javax.inject.Inject;
import javax.persistence.EntityManager;
import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Root;

import org.hawkular.accounts.api.NamedRole;
import org.hawkular.accounts.api.ResourceService;
import org.hawkular.accounts.api.internal.adapter.HawkularAccounts;
import org.hawkular.accounts.api.model.Persona;
import org.hawkular.accounts.api.model.PersonaResourceRole;
import org.hawkular.accounts.api.model.PersonaResourceRole_;
import org.hawkular.accounts.api.model.Resource;
import org.hawkular.accounts.api.model.Resource_;
import org.hawkular.accounts.api.model.Role;

/**
 * Main implementation of the {@link org.hawkular.accounts.api.ResourceService}. Consumers should get an instance of
 * this via CDI. This class should not be directly instantiated by the consumers.
 *
 * @author Juraci Paixão Kröhling
 */
@Stateless
@PermitAll
public class ResourceServiceImpl implements ResourceService {
    @Inject @HawkularAccounts
    EntityManager em;

    @Inject
    Persona persona;

    @Inject
    @NamedRole("SuperUser")
    Role superUser;

    @Override
    public Resource get(String id) {
        if (null == id) {
            throw new IllegalArgumentException("The given resource ID is invalid (null).");
        }

        CriteriaBuilder builder = em.getCriteriaBuilder();
        CriteriaQuery<Resource> query = builder.createQuery(Resource.class);
        Root<Resource> root = query.from(Resource.class);
        query.select(root);
        query.where(builder.equal(root.get(Resource_.id), id));

        List<Resource> results = em.createQuery(query).getResultList();
        if (results.size() == 1) {
            return results.get(0);
        }

        if (results.size() > 1) {
            throw new IllegalStateException("More than one resource found for ID " + id);
        }

        return null;
    }

    @Override
    public Resource create(String id, Persona persona) {
        if (null == persona) {
            throw new IllegalArgumentException("The specified persona is invalid (null).");
        }
        return create(id, null, persona);
    }

    @Override
    public Resource create(String id, Resource parent) {
        if (null == parent) {
            throw new IllegalArgumentException("The given parent resource is invalid (null).");
        }
        return create(id, parent, null);
    }

    @Override
    public Resource create(String id, Resource parent, Persona persona) {
        if (null == parent && null == persona) {
            throw new IllegalArgumentException("Either parent or persona should be provided when creating a resource");
        }

        Resource resource = new Resource(id, persona, parent);
        em.persist(resource);

        if (persona != null) {
            PersonaResourceRole resourceRole = new PersonaResourceRole(persona, superUser, resource);
            em.persist(resourceRole);
        }

        return resource;
    }

    @Override
    public void delete(String id) {
        if (null == id) {
            throw new IllegalArgumentException("The given resource ID is invalid (null).");
        }

        Resource resource = get(id);
        if (resource != null) {
            em.remove(resource);
        }
    }

    @Override
    public List<Resource> getByPersona(Persona persona) {
        if (null == persona) {
            throw new IllegalArgumentException("The given persona is invalid (null).");
        }

        CriteriaBuilder builder = em.getCriteriaBuilder();
        CriteriaQuery<Resource> query = builder.createQuery(Resource.class);
        Root<Resource> root = query.from(Resource.class);
        query.select(root);
        query.where(builder.equal(root.get(Resource_.persona), persona));

        return em.createQuery(query).getResultList();
    }

    @Override
    public void transfer(Resource resource, Persona persona) {
        resource.setPersona(persona);
        em.persist(resource);
        revokeAllForPersona(resource, persona);
        addRoleToPersona(resource, persona, superUser);
    }

    @Override
    public void revokeAllForPersona(Resource resource, Persona persona) {
        List<PersonaResourceRole> results = getRolesForPersona(resource, persona);
        results.stream().forEach(em::remove);
    }

    @Override
    public PersonaResourceRole addRoleToPersona(Resource resource, Persona persona, Role role) {
        // do we have already a PersonaResourceRole that matches the given specification?
        CriteriaBuilder builder = em.getCriteriaBuilder();
        CriteriaQuery<PersonaResourceRole> query = builder.createQuery(PersonaResourceRole.class);
        Root<PersonaResourceRole> root = query.from(PersonaResourceRole.class);
        query.select(root);
        query.where(
                builder.equal(root.get(PersonaResourceRole_.resource), resource),
                builder.equal(root.get(PersonaResourceRole_.persona), persona),
                builder.equal(root.get(PersonaResourceRole_.role), role)
        );

        List<PersonaResourceRole> results = em.createQuery(query).getResultList();
        if (results.size() == 1) {
            // yes, we have it already, just return it
            return results.get(0);
        }

        // no, we don't have it, create one
        PersonaResourceRole resourceRole = new PersonaResourceRole(persona, role, resource);
        em.persist(resourceRole);
        return resourceRole;
    }

    @Override
    public List<PersonaResourceRole> getRolesForPersona(Resource resource, Persona persona) {
        CriteriaBuilder builder = em.getCriteriaBuilder();
        CriteriaQuery<PersonaResourceRole> query = builder.createQuery(PersonaResourceRole.class);
        Root<PersonaResourceRole> root = query.from(PersonaResourceRole.class);
        query.select(root);
        query.where(
                builder.equal(root.get(PersonaResourceRole_.resource), resource),
                builder.equal(root.get(PersonaResourceRole_.persona), persona)
        );

        return em.createQuery(query).getResultList();
    }
}
